/*
* Licensed Materials - Property of IBM
* 5725-G92 (C) Copyright IBM Corp. 2006, 2012. All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

// Worklight comes with the jQuery 1.8.1 framework bundled inside. If you do not want to use it, please comment out the line below.
window.$ = window.jQuery = WLJQ;

// Global variables
var globalLong;				// GPS Longitude
var globalLat;				// GPS Latitude
var globalAddress = '(not available)';			// translated address info
var busyIndicator = null;	// busy indicator
var online = true;			// online status

//This is used by the app if run within the MBS
var localMemoriesList = new Array();

function wlCommonInit(){

	// Register the click events.
	$('#addMemBtn').bind('click', getGlobalAddress);
	$('#takePicBtn').bind('click', capturePhoto);
	$('#savePicBtn').bind('click', addMemoryToList);
	$(".memItem").live("click", function(){
		loadMemoryToViewPage($(this).attr("id"));
	});
	console.log('finish bind/live elements');
	//initialize the JSON Store collection (Open the store) and load all the memories to the listView.
	initCollection();
}

document.addEventListener("deviceready", onDeviceReady, false);

//Cordova is ready to be used!
function onDeviceReady() {
	// Get the GPS location
	getLocation();
}


$( '#cameraPage' ).live('pagebeforeshow',function(event){
	console.log( ' cameraPage() - pagebeforeshow' );
	$('#picMemoryTxt').val('');
	$('#picDetailTxt').val('');
	$('#captareImageImg').attr('src','images/placeholder_iPhoto.png');
	$('#captareImageImg').src = 'images/placeholder_iPhoto.png';
});

$( '#listPage' ).live('pagebeforeshow',function(event){
	console.log( ' listPage() - pagebeforeshow' );
	$('#memoryList').listview('refresh');
});

$( '#viewMemoryPage' ).live('pagebeforeshow',function(event){
	console.log( ' viewMemoryPage() - pagebeforeshow' );		
});


function validateMemory(ttl, dtl){
	//memValidateMessage
	if(ttl == null || ttl == undefined || ttl == ''){		
		$("#validatePop").popup( "open", {x:0, y:0});
		$("#memValidateMessage").html('  Please enter memory \'Title\'   ');
		return false;
	}
	if(dtl == null || dtl == undefined || dtl == ''){
		$("#memValidateMessage").html('  Please enter memory \'Description\'   ');
		$("#validatePop").popup( "open", {x:0, y:0});
		return false;
	}
	return true;
}

/**
 * Add Memory to the viewList ul (memoryList).
 */

function addMemoryToList(){
	
	var ttl = $('#picMemoryTxt').val();
	var dtl = $('#picDetailTxt').val();				
	var img = $('#captareImageImg').attr('src');
	if(validateMemory(ttl,dtl) == !true) return;
	
	$.mobile.showPageLoadingMsg();			
	var dt = new Date();
	console.log(ttl + " - " + dtl + " - " + dt.getTime() + " - " + img);
	var listItem = $('<li class="memItem" id="' + dt.getTime() + '" data-icon="false" data-theme="d"><a href="">' + ttl + '</a></li>');
	listItem.attr('data-icon', 'arrow-r');
	$("#memoryList").append(listItem);			
	$('#memoryList:visible').listview('refresh');
	$.mobile.hidePageLoadingMsg();	
	$.mobile.changePage('#homePage');	
	var obj = {	
				title: ttl, 
				description: dtl, 
				imgSrc: img,
				memId: dt.getTime(),
				memDate: dt.toString(),
				memLoc: globalAddress
			};
	
	//add memory to the local array (used by the MBS);
	localMemoriesList.push(obj);
	
	//add also the memory to the JSONStore.
	addMemoryToCollection(obj);
	
}



/**
 * Load all memories from the JSONStore to the listView
 */
function loadMemories(data){
	console.log("in loadMemories()");	
	$('#memoryList').empty();
	for(var i=0; i < data.length ; i++){			
			var item = data[i];	
			console.log(item);
			var listItem = $('<li class="memItem" id="' + item.json.memId + '" "data-icon="false" data-theme="d"><a href="">' + item.json.title + '</a></li>');
			listItem.attr('data-icon', 'arrow-r');
			$("#memoryList").append(listItem);
	}
		
	$('#memoryList:visible').listview('refresh');
	$.mobile.hidePageLoadingMsg();	
}


/*
 * Camera native api.
 * */


// Capture the image
function capturePhoto() {	
	console.log("in capturePhoto()");
    // Take picture using device camera and retrieve image as base64-encoded string
    navigator.camera.getPicture(onPhotoDataSuccess, onFail, { quality: 10,
      destinationType: navigator.camera.DestinationType.DATA_URL });
 }

//success callBack.
function onPhotoDataSuccess(imageData) {
	console.log("in onPhotoDataSuccess()");
	var smallImage = $('#captareImageImg');	
	$('#captareImageImg').attr('src', "data:image/jpeg;base64," + imageData);
	smallImage.src = "data:image/jpeg;base64," + imageData;
	smallImage.show();
  }

//failed callBack.
function onFail(message) {
	console.log("in onFail() - " + message);
    // alert('Failed because: ' + message);
}


/*
 * View memory
 * */
//will call find item in the JSONStore.
function loadMemoryToViewPage(id){
	//run on the MBS - NO JSONStore.
	if(memoriesCollection == null){
		for( var i=0; i<localMemoriesList.length;i++){
			if(localMemoriesList[i].memId == id){
				displayMemoryPage([{json: localMemoriesList[i]}]);
				return;
			}
		}
	}
	
	try{
		$.mobile.showPageLoadingMsg();
		console.log("loadMemoryToViewPage() - " + id);
		findMemory(id);
	}catch(e){
		console.log("Error:" + e);
	}	
}

//find callback - display the memory information.
function displayMemoryPage(data){	
	console.log("displayMemoryPage() - [0] - " + data[0]);
	//$('#viewMemoryPageTitle').html("View Memory");
	$('#memoryDescriptionDiv').html('');
	$('#memoryLocationDiv').html('');
	$('#memoryDateDiv').html('');			
	$('#memoryImageImg').attr('src', '');
	$('#memoryImageImg').src =  '';
	try{
		$('#viewMemoryPageTitle').html(data[0].json.title);
		$('#memoryDescriptionDiv').html(data[0].json.description);
		$('#memoryLocationDiv').html(data[0].json.memLoc);
		$('#memoryDateDiv').html(data[0].json.memDate);			
		$('#memoryImageImg').attr('src', data[0].json.imgSrc);
		$('#memoryImageImg').src =  data[0].json.imgSrc;
		$.mobile.changePage('#viewMemoryPage');
		$.mobile.hidePageLoadingMsg();
	}catch(e){
		console.log("Error:" + e);
	}
}

/////////////////////////////
// Get the GPS coordinates
/////////////////////////////

function getLocation() {
	
	console.log('getLocation');
	
	var win = function(position) {
		console.log('-getLocation:win');
		globalLat = position.coords.latitude;
		globalLong = position.coords.longitude;
		console.log('Obtained GPS location information: ' + globalLat + '/' + globalLong);
	};
	
	var lose = function(error) {
		console.log('-getLocation:lose');
		globalLat = 30.377047;
		globalLong = -91.123484;
		console.log('Failed to get GPS information, using default address.');
	};
	
	var options = { enableHighAccuracy: true };
	
	navigator.geolocation.getCurrentPosition(win, lose, options);
}

function getGlobalAddress(){
	
	getLocation();
	// alert('getGlobalAddress: ' + globalLat + ', ' + globalLong + ')');
	if (typeof(globalLat)  != 'undefined' || globalLat  != null ||
			typeof(globalLong) != 'undefined' || globalLong != null ){
			callGeoAdapter();
	} else { 
			globalAddress = '(Could not get GPS info)';
			// alert(globalAddress);
	}
}

////////////////////////////////////////////////////////////////
// Call the Worklight adapter and get the street/local address
////////////////////////////////////////////////////////////////

function callGeoAdapter(){

	if (!online){
		// store default location info for offline support
		console.log('callGeoAdapter: offline');
		globalAddress = '(Not connected to translate address for GPS)';
		// alert(globalAddress);
		// busyIndicator.hide();
		
	} else {
		// store translated address, to globalAddress
			console.log('callGeoAdapter: online');
			if (typeof(globalLat)  == 'undefined' || globalLat  == null ||
				typeof(globalLong) == 'undefined' || globalLong == null ){
				globalAddress = '(No valid GPS info)';
				// alert(globalAddress);
				// busyIndicator.hide();
				return;  
			}
		
			// Called when the adapter completes successfully 
			var win = function(result){
				globalAddress = result.invocationResult.results[0].formatted_address;
				// alert('globalAddress[' + globalAddress.length + '] '+ globalAddress);
				if(globalAddress.length == 0){
					globalAddress = '(Could not translate address via adapter)';
				}
				console.log('-callGeoAdapter:win - address: ' + globalAddress);
				return;
			};
		
			// Called when the adapter does NOT complete successfully 
			var lose = function(){
				console.log('-callGeoAdapter:lose - Failed to obtain address for GPS');
				globalAddress = '(Could not translate address for given GPS)';
				// alert(globalAddress);
				return;
			};
			
			var invocationData = {
					adapter    : 'GPSLocator',
				    procedure  : 'getLocation',
				    parameters : [globalLat, globalLong]
			};
			
			var options = {
				onSuccess : win,
				onFailure : lose
			};
		
			WL.Client.invokeProcedure(invocationData, options);
	}
}

